Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(315)

Unified Diff: runtime/include/dart_api.h

Issue 2068833002: Change Dart_DefaultCanonicalizeUrl to accept the library url string instead of a library, this is u… (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: address-code-review-comments Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/loader.cc ('k') | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h
index e27d70e44e4217130f68a6abc9af3ca992f477c1..123064cd193eb4327e2a4e848b7127e9649227b2 100755
--- a/runtime/include/dart_api.h
+++ b/runtime/include/dart_api.h
@@ -2692,15 +2692,15 @@ DART_EXPORT Dart_Handle Dart_SetLibraryTagHandler(
* This canonicalization function should be sufficient for most
* embedders to implement the Dart_kCanonicalizeUrl tag.
*
* \param library The library relative to which the url is being
* resolved.
* \param url The url being resolved and canonicalized. This
* parameter is a string handle.
*
* \return If no error occurs, a String object is returned. Otherwise
* an error handle is returned.
*/
-DART_EXPORT Dart_Handle Dart_DefaultCanonicalizeUrl(Dart_Handle library,
+DART_EXPORT Dart_Handle Dart_DefaultCanonicalizeUrl(Dart_Handle base_url,
Dart_Handle url);
/**
« no previous file with comments | « runtime/bin/loader.cc ('k') | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
@@ -2692,15 +2692,15 @@ DART_EXPORT Dart_Handle Dart_SetLibraryTagHandler(
* embedders to implement the Dart_kCanonicalizeUrl tag.
*
- * \param library The library relative to which the url is being
- * resolved.
+ * \param base_url The base url relative to which the url is
+ * being resolved.
* \param url The url being resolved and canonicalized. This
* parameter is a string handle.

Powered by Google App Engine
This is Rietveld 408576698